==> graphpy-0.0.8-py2-none-any.whl: graphpy/edge.py <==
"""
Implementation of an edge, as used in graphs
"""


################################################################################
#                                                                              #
#                                  Undirected                                  #
#                                                                              #
################################################################################


class UndirectedEdge(object):

    def __init__(self, v0, v1):
        self._vertices = frozenset([v0, v1])
        self._is_self_edge = v0 == v1

    def __repr__(self):
        vertices = (tuple(self._vertices) if not self._is_self_edge else
                    tuple(self._vertices) * 2)
        return "Edge(%s, %s)" % (vertices[0], vertices[1])

    def __str__(self):
        vertices = (tuple(self._vertices) if not self._is_self_edge else
                    tuple(self._vertices) * 2)
        return "E(%s, %s)" % (str(vertices[0]), str(vertices[1]))

    def __eq__(self, other):
        return self._vertices == other.vertices

    def __ne__(self, other):
        return not self.__eq__(other)

    def __hash__(self):
        return hash(self._vertices)

    @property
    def vertices(self):
        return self._vertices

    @property
    def is_self_edge(self):
        return self._is_self_edge


################################################################################
#                                                                              #
#                                   Directed                                   #
#                                                                              #
################################################################################


class DirectedEdge(object):

    def __init__(self, v_from, v_to):
        self._v_from = v_from
        self._v_to = v_to

    def __repr__(self):
        return "Edge(%s, %s)" % (self._v_from, self._v_to)

    def __str__(self):
        return "E(%s, %s)" % (str(self._v_from), str(self._v_to))

    def __eq__(self, other):
        return (self._v_from, self._v_to) == (other.v_from, other.v_to)

    def __ne__(self, other):
        return not self.__eq__(other)

    def __hash__(self):
        return hash((self._v_from, self._v_to))

    @property
    def v_from(self):
        return self._v_from

    @property
    def v_to(self):
        return self._v_to

==> graphpy-0.0.9-py2-none-any.whl: graphpy/edge.py <==
"""
Implementation of an edge, as used in graphs
"""


################################################################################
#                                                                              #
#                                  Undirected                                  #
#                                                                              #
################################################################################


class UndirectedEdge(object):

    def __init__(self, v0, v1, attrs=None):
        self._vertices = frozenset([v0, v1])
        self._attrs = attrs or {}
        self._is_self_edge = v0 == v1

    def __repr__(self):
        vertices = (tuple(self._vertices) if not self._is_self_edge else
                    tuple(self._vertices) * 2)
        return "Edge(%s, %s)" % (vertices[0], vertices[1])

    def __str__(self):
        vertices = (tuple(self._vertices) if not self._is_self_edge else
                    tuple(self._vertices) * 2)
        return "E(%s, %s)" % (str(vertices[0]), str(vertices[1]))

    def __eq__(self, other):
        return self._vertices == other.vertices

    def __ne__(self, other):
        return not self.__eq__(other)

    def __hash__(self):
        return hash(self._vertices)

    @property
    def vertices(self):
        return self._vertices

    @property
    def attrs(self):
        return self._attrs

    @property
    def is_self_edge(self):
        return self._is_self_edge

    def get(self, attr):
        return self._attrs.get(attr)

    def set(self, attr, value):
        self._attrs[attr] = value

    def del_attr(self, attr):
        del self._attrs[attr]


################################################################################
#                                                                              #
#                                   Directed                                   #
#                                                                              #
################################################################################


class DirectedEdge(object):

    def __init__(self, v_from, v_to, attrs=None):
        self._v_from = v_from
        self._v_to = v_to
        self._attrs = attrs or {}

    def __repr__(self):
        return "Edge(%s, %s)" % (self._v_from, self._v_to)

    def __str__(self):
        return "E(%s, %s)" % (str(self._v_from), str(self._v_to))

    def __eq__(self, other):
        return (self._v_from, self._v_to) == (other.v_from, other.v_to)

    def __ne__(self, other):
        return not self.__eq__(other)

    def __hash__(self):
        return hash((self._v_from, self._v_to))

    @property
    def v_from(self):
        return self._v_from

    @property
    def v_to(self):
        return self._v_to

    @property
    def attrs(self):
        return self._attrs

    def get(self, attr):
        return self._attrs.get(attr)

    def set(self, attr, value):
        self._attrs[attr] = value

    def del_attr(self, attr):
        del self._attrs[attr]
